==> Qt5.6.3-Android-arm-gcc-NDKr10e-xmacOS-x86_64-AppleClang11.0.0-20200105.tar.xz: Qt5.6.3-Android-arm-gcc-NDKr10e-xmacOS-x86_64-AppleClang11.0.0-20200105/lib/cmake/Qt5AndroidExtras/Qt5AndroidExtrasConfig.cmake <==

if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

set(_qt5AndroidExtras_install_prefix "")

# For backwards compatibility only. Use Qt5AndroidExtras_VERSION instead.
set(Qt5AndroidExtras_VERSION_STRING 5.6.3)

set(Qt5AndroidExtras_LIBRARIES Qt5::AndroidExtras)

macro(_qt5_AndroidExtras_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::AndroidExtras\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

macro(_populate_AndroidExtras_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::AndroidExtras APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set(imported_location "/lib/${LIB_LOCATION}")
    _qt5_AndroidExtras_check_file_exists(${imported_location})
    set_target_properties(Qt5::AndroidExtras PROPERTIES
        "INTERFACE_LINK_LIBRARIES" "${_Qt5AndroidExtras_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        "IMPORTED_SONAME_${Configuration}" "libQt5AndroidExtras.so"
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5AndroidExtras_LIB_DEPENDENCIES}"
    )

endmacro()

if (NOT TARGET Qt5::AndroidExtras)

    set(_Qt5AndroidExtras_OWN_INCLUDE_DIRS "/include/" "/include/QtAndroidExtras")
    set(Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5AndroidExtras_OWN_INCLUDE_DIRS})
        _qt5_AndroidExtras_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5AndroidExtras_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS})
            _qt5_AndroidExtras_check_file_exists(${_dir})
        endforeach()
    endif()

    set(Qt5AndroidExtras_INCLUDE_DIRS ${_Qt5AndroidExtras_OWN_INCLUDE_DIRS})

    set(Qt5AndroidExtras_DEFINITIONS -DQT_ANDROIDEXTRAS_LIB)
    set(Qt5AndroidExtras_COMPILE_DEFINITIONS QT_ANDROIDEXTRAS_LIB)
    set(_Qt5AndroidExtras_MODULE_DEPENDENCIES "Core")


    set(_Qt5AndroidExtras_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5AndroidExtras_FIND_REQUIRED)
        set(_Qt5AndroidExtras_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5AndroidExtras_FIND_DEPENDENCIES_QUIET)
    if (Qt5AndroidExtras_FIND_QUIETLY)
        set(_Qt5AndroidExtras_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5AndroidExtras_FIND_VERSION_EXACT)
    if (Qt5AndroidExtras_FIND_VERSION_EXACT)
        set(_Qt5AndroidExtras_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5AndroidExtras_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5AndroidExtras_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                5.6.3 ${_Qt5AndroidExtras_FIND_VERSION_EXACT}
                ${_Qt5AndroidExtras_DEPENDENCIES_FIND_QUIET}
                ${_Qt5AndroidExtras_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5AndroidExtras_FOUND False)
            return()
        endif()

        list(APPEND Qt5AndroidExtras_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5AndroidExtras_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5AndroidExtras_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5AndroidExtras_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5AndroidExtras_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5AndroidExtras_LIB_DEPENDENCIES "Qt5::Core")


    add_library(Qt5::AndroidExtras SHARED IMPORTED)

    set_property(TARGET Qt5::AndroidExtras PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5AndroidExtras_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::AndroidExtras PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_ANDROIDEXTRAS_LIB)

    _populate_AndroidExtras_target_properties(RELEASE "libQt5AndroidExtras.so" "" )




    file(GLOB pluginTargets "${CMAKE_CURRENT_LIST_DIR}/Qt5AndroidExtras_*Plugin.cmake")

    macro(_populate_AndroidExtras_plugin_properties Plugin Configuration PLUGIN_LOCATION)
        set_property(TARGET Qt5::${Plugin} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

        set(imported_location "/plugins/${PLUGIN_LOCATION}")
        _qt5_AndroidExtras_check_file_exists(${imported_location})
        set_target_properties(Qt5::${Plugin} PROPERTIES
            "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        )
    endmacro()

    if (pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()




_qt5_AndroidExtras_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5AndroidExtrasConfigVersion.cmake")

endif()

==> Qt5.9.9-Android-arm-gcc-NDKr10e-xmacOS-x86_64-AppleClang11.0.0-20200105.tar.xz: Qt5.9.9-Android-arm-gcc-NDKr10e-xmacOS-x86_64-AppleClang11.0.0-20200105/lib/cmake/Qt5AndroidExtras/Qt5AndroidExtrasConfig.cmake <==

if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_IMPORT_PREFIX "${CMAKE_CURRENT_LIST_FILE}" PATH)
# Use original install prefix when loaded through a
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${_IMPORT_PREFIX}" REALPATH)
get_filename_component(_realOrig "/lib/cmake/Qt5AndroidExtras" REALPATH)
if(_realCurr STREQUAL _realOrig)
    get_filename_component(_qt5AndroidExtras_install_prefix "/lib/../" ABSOLUTE)
else()
    get_filename_component(_qt5AndroidExtras_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)
endif()
unset(_realOrig)
unset(_realCurr)
unset(_IMPORT_PREFIX)

# For backwards compatibility only. Use Qt5AndroidExtras_VERSION instead.
set(Qt5AndroidExtras_VERSION_STRING 5.9.9)

set(Qt5AndroidExtras_LIBRARIES Qt5::AndroidExtras)

macro(_qt5_AndroidExtras_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::AndroidExtras\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

macro(_populate_AndroidExtras_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::AndroidExtras APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set(imported_location "${_qt5AndroidExtras_install_prefix}/lib/${LIB_LOCATION}")
    _qt5_AndroidExtras_check_file_exists(${imported_location})
    set_target_properties(Qt5::AndroidExtras PROPERTIES
        "INTERFACE_LINK_LIBRARIES" "${_Qt5AndroidExtras_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        "IMPORTED_SONAME_${Configuration}" "libQt5AndroidExtras.so"
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5AndroidExtras_LIB_DEPENDENCIES}"
    )

endmacro()

if (NOT TARGET Qt5::AndroidExtras)

    set(_Qt5AndroidExtras_OWN_INCLUDE_DIRS "${_qt5AndroidExtras_install_prefix}/include/" "${_qt5AndroidExtras_install_prefix}/include/QtAndroidExtras")
    set(Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5AndroidExtras_OWN_INCLUDE_DIRS})
        _qt5_AndroidExtras_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5AndroidExtras_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS})
            _qt5_AndroidExtras_check_file_exists(${_dir})
        endforeach()
    endif()

    set(Qt5AndroidExtras_INCLUDE_DIRS ${_Qt5AndroidExtras_OWN_INCLUDE_DIRS})

    set(Qt5AndroidExtras_DEFINITIONS -DQT_ANDROIDEXTRAS_LIB)
    set(Qt5AndroidExtras_COMPILE_DEFINITIONS QT_ANDROIDEXTRAS_LIB)
    set(_Qt5AndroidExtras_MODULE_DEPENDENCIES "Core")


    set(Qt5AndroidExtras_OWN_PRIVATE_INCLUDE_DIRS ${Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS})

    set(_Qt5AndroidExtras_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5AndroidExtras_FIND_REQUIRED)
        set(_Qt5AndroidExtras_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5AndroidExtras_FIND_DEPENDENCIES_QUIET)
    if (Qt5AndroidExtras_FIND_QUIETLY)
        set(_Qt5AndroidExtras_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5AndroidExtras_FIND_VERSION_EXACT)
    if (Qt5AndroidExtras_FIND_VERSION_EXACT)
        set(_Qt5AndroidExtras_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5AndroidExtras_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5AndroidExtras_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                5.9.9 ${_Qt5AndroidExtras_FIND_VERSION_EXACT}
                ${_Qt5AndroidExtras_DEPENDENCIES_FIND_QUIET}
                ${_Qt5AndroidExtras_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5AndroidExtras_FOUND False)
            return()
        endif()

        list(APPEND Qt5AndroidExtras_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5AndroidExtras_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5AndroidExtras_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5AndroidExtras_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5AndroidExtras_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5AndroidExtras_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5AndroidExtras_LIB_DEPENDENCIES "Qt5::Core")


    add_library(Qt5::AndroidExtras SHARED IMPORTED)

    set_property(TARGET Qt5::AndroidExtras PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5AndroidExtras_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::AndroidExtras PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_ANDROIDEXTRAS_LIB)

    set(_Qt5AndroidExtras_PRIVATE_DIRS_EXIST TRUE)
    foreach (_Qt5AndroidExtras_PRIVATE_DIR ${Qt5AndroidExtras_OWN_PRIVATE_INCLUDE_DIRS})
        if (NOT EXISTS ${_Qt5AndroidExtras_PRIVATE_DIR})
            set(_Qt5AndroidExtras_PRIVATE_DIRS_EXIST FALSE)
        endif()
    endforeach()

    if (_Qt5AndroidExtras_PRIVATE_DIRS_EXIST
        AND NOT CMAKE_VERSION VERSION_LESS 3.0.0 )
        add_library(Qt5::AndroidExtrasPrivate INTERFACE IMPORTED)
        set_property(TARGET Qt5::AndroidExtrasPrivate PROPERTY
            INTERFACE_INCLUDE_DIRECTORIES ${Qt5AndroidExtras_OWN_PRIVATE_INCLUDE_DIRS}
        )
        set(_Qt5AndroidExtras_PRIVATEDEPS)
        foreach(dep ${_Qt5AndroidExtras_LIB_DEPENDENCIES})
            if (TARGET ${dep}Private)
                list(APPEND _Qt5AndroidExtras_PRIVATEDEPS ${dep}Private)
            endif()
        endforeach()
        set_property(TARGET Qt5::AndroidExtrasPrivate PROPERTY
            INTERFACE_LINK_LIBRARIES Qt5::AndroidExtras ${_Qt5AndroidExtras_PRIVATEDEPS}
        )
    endif()

    _populate_AndroidExtras_target_properties(RELEASE "libQt5AndroidExtras.so" "" )




    file(GLOB pluginTargets "${CMAKE_CURRENT_LIST_DIR}/Qt5AndroidExtras_*Plugin.cmake")

    macro(_populate_AndroidExtras_plugin_properties Plugin Configuration PLUGIN_LOCATION)
        set_property(TARGET Qt5::${Plugin} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

        set(imported_location "${_qt5AndroidExtras_install_prefix}/plugins/${PLUGIN_LOCATION}")
        _qt5_AndroidExtras_check_file_exists(${imported_location})
        set_target_properties(Qt5::${Plugin} PROPERTIES
            "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        )
    endmacro()

    if (pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()




_qt5_AndroidExtras_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5AndroidExtrasConfigVersion.cmake")

endif()
